MeDIL
=====

MeDIL is a Python package for causal factor analysis, using the
measurement dependence inducing latent (MeDIL) causal model
framework\ `1 <#uai_paper>`__. In addition to simple linear Gaussian
models, MeDIL also supports deep generative models\ `2 <#ncfa_paper>`__.

More information can be found in the
`documentation <https://medil.causal.dev>`__.

Support, Bugs, and Contributing
-------------------------------

If you have any questions, suggestions, feedback, or bugs to report,
please `open an issue on
Gitlab <https://gitlab.com/alex-markham/medil/issues/new>`__ or `on
Github <https://github.com/Alex-Markham/medil/issues/new>`__ or `contact
me <https://causal.dev/#contact>`__. Additionally, if you would like to
use this package or any of its code in your research, or to contribute
to this package, feel free (but not obliged) to `contact
me <https://causal.dev/#contact>`__.

License
-------

See
`LICENSE <https://gitlab.com/alex-markham/medil/blob/master/LICENSE.md>`__,
which is the GNU Affero General Public License version 3 or later.

Changelog
---------

See
`CHANGELOG <https://gitlab.com/alex-markham/medil/blob/master/CHANGELOG.md>`__
for a history of the already implemented features, works in progress,
and future feature ideas.

References
----------

1. Alex Markham & Moritz Grosse-Wentrup (2020). Measurement Dependence
Inducing Latent Causal Models. In *Conference on Uncertainty in
Artificial Intelligence (UAI)* PMLR 124:590–599. URL:
http://proceedings.mlr.press/v124/markham20a/markham20a.pdf.
`arXiv:1910.08778 <https://arxiv.org/abs/1910.08778>`__ [stat.ML].

2. Alex Markham, Mingyu Liu, Bryon Aragam, Liam Solus (2023).
Neuro-Causal Factor Analysis. *prepint*.
`arXiv:2305.19802 <https://arxiv.org/abs/2305.19802>`__ [stat.ML].
